@@ -9,12 +9,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="alarmwindow.cpp" line="59"/>
+        <location filename="alarmwindow.cpp" line="61"/>
         <source>alarms in next %1 h</source>
         <translation type="unfinished">будильники (на %1 ч)</translation>
     </message>
     <message>
-        <location filename="alarmwindow.cpp" line="166"/>
+        <location filename="alarmwindow.cpp" line="192"/>
         <source>--:--</source>
         <translation type="unfinished"></translation>
     </message>	
@@ -26,56 +26,76 @@
         <source>Next Alarm settings</source>
         <translation type="unfinished">Настройки Next Alarm</translation>
     </message>
-    <message>
-        <location filename="settingsdialog.ui" line="32"/>
-        <source>Lines</source>
-        <translation type="unfinished">Строк</translation>
-    </message>
-    <message>
-        <location filename="settingsdialog.ui" line="52"/>
-        <source>Width</source>
-        <translation type="unfinished">Ширина</translation>
-    </message>	
-    <message>
-        <location filename="settingsdialog.ui" line="79"/>
+	<message>
+        <location filename="settingsdialog.ui" line="38"/>
         <source>Font</source>
         <translation type="unfinished">Шрифт</translation>
-    </message>
-    <message>
-        <location filename="settingsdialog.ui" line="109"/>
+    </message>	
+	<message>
+        <location filename="settingsdialog.ui" line="68"/>
         <source>B</source>
         <translation type="unfinished">Ж</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="127"/>
+        <location filename="settingsdialog.ui" line="86"/>
         <source>I</source>
         <translation type="unfinished">К</translation>
-    </message>
+    </message>	
     <message>
-        <location filename="settingsdialog.ui" line="134"/>
+        <location filename="settingsdialog.ui" line="103"/>
         <source>Color</source>
         <translation type="unfinished">цвет</translation>
-    </message>
+    </message>	
     <message>
-        <location filename="settingsdialog.ui" line="141"/>
+        <location filename="settingsdialog.ui" line="110"/>
         <source>12:48</source>
         <translation type="unfinished"></translation>
+    </message>	
+    <message>
+        <location filename="settingsdialog.ui" line="132"/>
+        <source>Filter</source>
+        <translation type="unfinished">Фильтр</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="149"/>
+        <source>Alarms only</source>
+        <translation type="unfinished">Будильники</translation>
     </message>
     <message>
         <location filename="settingsdialog.ui" line="154"/>
-        <source>Size</source>
-        <translation type="unfinished">размер</translation>
+        <source>Будильники + Календарь</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="180"/>
-        <source>Only std Alarms</source>
-        <translation type="unfinished">Только стандартные</translation>
+        <location filename="settingsdialog.ui" line="159"/>
+        <source>Все события</source>
+        <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="settingsdialog.ui" line="167"/>
+        <source>Lines</source>
+        <translation type="unfinished">Строк</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="193"/>
+        <source>Width</source>
+        <translation type="unfinished">Ширина</translation>
+    </message>	
+    <message>
+        <location filename="settingsdialog.ui" line="222"/>
+        <source>recurrent</source>
+        <translation type="unfinished">повторяющиеся</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="229"/>
+        <source>Frame (h)</source>
+        <translation type="unfinished">Диапазон (ч)</translation>
+    </message>    
     <message>
         <location filename="settingsdialog.ui" line="187"/>
-        <source>TimeRemain</source>
+        <source>Time Remain</source>
         <translation type="unfinished">Оставшееся время</translation>
-    </message>
+    </message>    
     <message>
         <location filename="settingsdialog.ui" line="194"/>
         <source>Header</source>
@@ -83,28 +103,48 @@
     </message>
     <message>
         <location filename="settingsdialog.ui" line="201"/>
-        <source>Alarm Title</source>
-        <translation type="unfinished">Имя будильника</translation>
+        <source>Title</source>
+        <translation type="unfinished">Название</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="214"/>
+        <location filename="settingsdialog.ui" line="294"/>
+        <source>Show empty</source>
+        <translation type="unfinished">Показывать пустой</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.ui" line="307"/>
         <source>About</source>
         <translation type="unfinished">О программе</translation>
     </message>
     <message>
-        <location filename="settingsdialog.ui" line="221"/>
+        <location filename="settingsdialog.ui" line="314"/>
         <source>About Qt</source>
         <translation type="unfinished">Qt</translation>
     </message>
     <message>
-        <location filename="settingsdialog.cpp" line="102"/>
+        <location filename="settingsdialog.cpp" line="118"/>
+        <source>Next Alarm</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="119"/>
+        <source>Developed with</source>
+        <translation type="unfinished">Написано на</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="120"/>
+        <source>Desktop widget, showing time of next alarms</source>
+        <translation type="unfinished">Виджет, отображающий приближающиеся будильники</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="121"/>
+        <source>Send reports to:</source>
+        <translation type="unfinished">Написать автору</translation>
+    </message>
+    <message>
+        <location filename="settingsdialog.cpp" line="128"/>
         <source>About Next Alarm</source>
         <translation type="unfinished">О программе Next Alarm</translation>
     </message>
-    <message>
-        <location filename="settingsdialog.cpp" line="103"/>
-        <source>&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6&lt;br&gt;Using &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Desktop widget, showing time of next alarm</source>
-        <translation type="unfinished">&lt;b&gt;Next Alarm&lt;/b&gt; 0.1.6&lt;br&gt;Написано на &lt;b&gt;Qt 4.6.2&lt;/b&gt;&lt;br&gt;Copyright (c) 2010 Avis&lt;br&gt;&lt;a href=&quot;mailto:avis@allnokia.ru&quot;&gt;avis@allnokia.ru&lt;/a&gt;&lt;br&gt;&lt;br&gt;Виджет, отображающий время следующего будильника</translation>
-    </message>
 </context>
 </TS>
