@@ -7,6 +7,13 @@
 #include <QMessageBox>
 #include <QFontDatabase>
 
+#define STR_VERSION "0.2.0"
+#define STR_CRLF "<br>"
+#define STR_QT_VERSION "<b>Qt 4.6.2</b>"
+#define STR_COPYRIGHT "Copyright (c) 2010 Avis"
+#define STR_EMAIL "<a href=\"mailto:avis@allnokia.ru\">avis@allnokia.ru</a>"
+#define STR_DONATE "<a href=https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=TBV3R4AU2PVHS>Donate</a>"
+
 SettingsDialog::SettingsDialog(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::SettingsDialog)
@@ -57,7 +64,11 @@ void SettingsDialog::dumpSettings() const
     nalarmsettings::getInstance().setShowHeader(ui->cbShowHeader->isChecked());
     nalarmsettings::getInstance().setShowRemain(ui->chbRemain->isChecked());
     nalarmsettings::getInstance().setShowTitle(ui->chbTitle->isChecked());
-    nalarmsettings::getInstance().setStdOnly(ui->chbStdOnly->isChecked());
+
+    nalarmsettings::getInstance().setShowRecurrent(ui->chbRecurrent->isChecked());
+    nalarmsettings::getInstance().setShowEmpty(ui->chbEmptyVisible->isChecked());
+    nalarmsettings::getInstance().setAlarmFilter(ui->cbFilter->currentIndex());
+    nalarmsettings::getInstance().setTimeFrame(ui->spinTimeFrame->value());
 }
 
 void SettingsDialog::loadSettings()
@@ -70,7 +81,12 @@ void SettingsDialog::loadSettings()
     ui->cbShowHeader->setChecked(nalarmsettings::getInstance().isShowHeader());
     ui->chbRemain->setChecked(nalarmsettings::getInstance().isShowRemain());
     ui->chbTitle->setChecked(nalarmsettings::getInstance().isShowTitle());
-    ui->chbStdOnly->setChecked(nalarmsettings::getInstance().isStdOnly());
+
+    ui->chbRecurrent->setChecked(nalarmsettings::getInstance().isShowRecurrent());
+    ui->chbEmptyVisible->setChecked(nalarmsettings::getInstance().isShowEmpty());
+    ui->cbFilter->setCurrentIndex(nalarmsettings::getInstance().alarmFilter());
+    ui->spinTimeFrame->setValue(nalarmsettings::getInstance().timeFrame());
+
     ui->spinSize->setValue(wSize);
     ui->spinWidth->setValue(nalarmsettings::getInstance().getWidth());
     {
@@ -99,12 +115,17 @@ void SettingsDialog::loadSettings()
 
 void SettingsDialog::showAbout()
 {
-    QMessageBox::about(this, tr("About Next Alarm"),
-                        tr("<b>Next Alarm</b> 0.1.6<br>"
-                        "Using <b>Qt 4.6.2</b><br>"
-                        "Copyright (c) 2010 Avis<br>"
-                        "<a href=\"mailto:avis@allnokia.ru\">avis@allnokia.ru</a><br><br>"
-                        "Desktop widget, showing time of next alarm"));
+    QString msgName = tr("Next Alarm");
+    QString msgDeveloped = tr("Developed with");
+    QString msgDescr = tr("Desktop widget, showing time of next alarms");
+    QString msgReports = tr("Send reports to:");
+    QString msgText = "<b>" + msgName + "</b> " + STR_VERSION + STR_CRLF;
+    msgText += msgDescr + STR_CRLF;
+    msgText += msgDeveloped + " " + STR_QT_VERSION + STR_CRLF + STR_CRLF;
+    msgText += msgReports + " " + STR_EMAIL + STR_CRLF;
+    msgText += QString(STR_DONATE) + STR_CRLF + STR_CRLF;
+    msgText += STR_COPYRIGHT;
+    QMessageBox::about(this, tr("About Next Alarm"),msgText);
 }
 
 void SettingsDialog::showQtAbout()
